@@ -5,10 +5,10 @@ use strict;
 use warnings;
 
 # Modules.
-use Error::Pure::Die qw(err);
+use Error::Pure::ErrorList qw(err);
 
 # Error.
-err '1', '2', '3';
+err '1';
 
 # Output:
-# 1 at example2.pl line 9.
\ No newline at end of file
+# #Error [example1.pl:9] 1
\ No newline at end of file
